@@ -1,4 +1,11 @@
 #!/usr/bin/env bash
+# jenkins build helper script for openbsc.  This is how we build on jenkins.osmocom.org
+
+if ! [ -x "$(command -v osmo-build-dep.sh)" ]; then
+	echo "Error: We need to have scripts/osmo-deps.sh from http://git.osmocom.org/osmo-ci/ in PATH !"
+	exit 2
+fi
+
 
 set -ex
 
@@ -7,22 +14,18 @@ deps="$base/deps"
 inst="$deps/install"
 export deps inst
 
-mkdir "$deps" || true
-rm -rf "$inst"
+osmo-clean-workspace.sh
 
+mkdir "$deps" || true
 osmo-build-dep.sh libosmocore "" ac_cv_path_DOXYGEN=false
 
-"$deps"/libosmocore/contrib/verify_value_string_arrays_are_terminated.py $(find . -name "*.[hc]")
+verify_value_string_arrays_are_terminated.py $(find . -name "*.[hc]")
 
 export PKG_CONFIG_PATH="$inst/lib/pkgconfig:$PKG_CONFIG_PATH"
 export LD_LIBRARY_PATH="$inst/lib"
 
-if [ "x$IU" = "x--enable-iu" ]; then
-	sccp_branch="old_sua"
-	osmo_iuh_branch="old_sua"
-fi
-
-PARALLEL_MAKE="" osmo-build-dep.sh libsmpp34
+osmo-build-dep.sh libosmo-abis
+osmo-build-dep.sh libosmo-netif
 
 set +x
 echo
@@ -39,6 +42,8 @@ $MAKE $PARALLEL_MAKE
 LD_LIBRARY_PATH="$inst/lib" $MAKE check \
   || cat-testlogs.sh
 LD_LIBRARY_PATH="$inst/lib" \
-  DISTCHECK_CONFIGURE_FLAGS="--enable-osmo-bsc --enable-nat $SMPP $MGCP $IU --enable-vty-tests --enable-external-tests" \
+  DISTCHECK_CONFIGURE_FLAGS="$MGCP --enable-vty-tests --enable-external-tests" \
   $MAKE distcheck \
   || cat-testlogs.sh
+
+osmo-clean-workspace.sh
