@@ -17,7 +17,7 @@ extern struct cmd_element cfg_no_description_cmd;
 
 enum mgcp_vty_node {
 	MGCP_NODE = _LAST_OSMOVTY_NODE + 1,
-	TRUNK_NODE = _LAST_OSMOVTY_NODE + 2,
+	TRUNK_NODE,
 };
 
 struct log_info;
